#!/usr/bin/env python3

if __name__ == "__main__":
    a = 10
    print(f"hello {a+1} world")
